@@ -3,12 +3,16 @@
  Documentation generator for the Lua/APR binding.
 
  Author: Peter Odding <peter@peterodding.com>
- Last Change: February 19, 2011
+ Last Change: March 28, 2011
  Homepage: http://peterodding.com/code/lua/apr/
  License: MIT
 
 ]]
 
+-- We only need this for the version number.
+-- TODO Might as well extract it directly from apr.lua?
+local apr = require 'apr'
+
 -- Files containing documentation fragments (the individual lines enable
 -- automatic rebasing between git feature branches and the master branch).
 local SOURCES = [[
@@ -24,6 +28,9 @@ local SOURCES = [[
   io_file.c
   io_net.c
   io_pipe.c
+  memcache.c
+  getopt.c
+  http.c
   proc.c
   shm.c
   str.c
@@ -65,7 +72,7 @@ local function getmodule(name, file, header)
   return value
 end
 
-local function message(string, ...)
+local function message(...)
   io.stderr:write(fmt(...), '\n')
 end
 
@@ -145,7 +152,7 @@ will iterate over all lines. This function does not close the file when the loop
 local coverage = {}
 for filename in SOURCES:gmatch '%S+' do
   if filename:find '%.c$' and filename ~= 'errno.c' then
-    local gcov = assert(io.popen('gcov -o src -nf ' .. filename))
+    local gcov = assert(io.popen('gcov -o src -nf ' .. filename .. ' 2>/dev/null'))
     local cfun
     local count = 0
     for line in gcov:lines() do
@@ -201,9 +208,7 @@ for filename in SOURCES:gmatch '%S+' do
     local pattern = '\n/%*([^\n]-%->.-)%*/\n\n%w[^\n]- ([%w_]+)%([^\n]-%)\n(%b{})'
     for docblock, funcname, funcbody in source:gmatch(pattern) do
       local signature, description = docblock:match '^([^\n]- %-> [^\n]+)(\n.-)$'
-      if not signature then
-        message("%s: Function %s doesn't have a signature?!", filename, funcname)
-      else
+      if signature then
         description = mungedesc(signature, description)
         local by = funcbody:find 'luaL_checklstring' or funcbody:find 'datum_check' or funcbody:find 'lua_pushlstring'
         local bn = funcbody:find 'luaL_checkstring' or funcbody:find 'lua_tostring' or funcbody:find 'luaL_optstring' or funcbody:find 'lua_pushstring'
@@ -215,7 +220,7 @@ for filename in SOURCES:gmatch '%S+' do
       end
     end
   elseif not filename:find '[\\/]examples[\\/]' then
-    local pattern = '\n(\n%-%- apr%.[%w_]+%(.-\n%-%-[^\n]*)\n\nfunction (apr%.[%w_]+)%('
+    local pattern = '\n(\n%-%- (apr%.[%w_]+)%(.-\n%-%-[^\n]*)\n\n'
     for docblock, funcname in source:gmatch(pattern) do
       docblock = trim(docblock:gsub('\n%-%- ?', '\n'))
       local signature, description = docblock:match '^([^\n]- %-> [^\n]+)(\n.-)$'
@@ -297,6 +302,7 @@ local function sig2privfun(s)
     s = s:gsub('^prepared_statement_', 'dbp_')
     s = s:gsub('^result_set_', 'dbr_')
     s = s:gsub('^xml_parser_', 'xml_')
+    s = s:gsub('^mc_client_', 'mc_')
     return s
   end
 end
@@ -374,6 +380,10 @@ local bsignore = {
   ['apr.dbd'] = true,
   ['apr.os_default_encoding'] = true,
   ['apr.os_locale_encoding'] = true,
+  ['apr.parse_cookie_header'] = true,
+  ['apr.parse_headers'] = true,
+  ['apr.parse_multipart'] = true,
+  ['apr.parse_query_string'] = true,
   ['apr.platform_get'] = true,
   ['apr.proc_fork'] = true,
   ['apr.strfsize'] = true,
@@ -386,6 +396,19 @@ local bsignore = {
   ['driver:driver'] = true,
   ['driver:transaction_mode'] = true,
   ['file:lock'] = true,
+  ['mc_client:add'] = true,
+  ['mc_client:add_server'] = true,
+  ['mc_client:add_server'] = true,
+  ['mc_client:decr'] = true,
+  ['mc_client:delete'] = true,
+  ['mc_client:find_server'] = true,
+  ['mc_client:find_server'] = true,
+  ['mc_client:get'] = true,
+  ['mc_client:incr'] = true,
+  ['mc_client:replace'] = true,
+  ['mc_client:set'] = true,
+  ['mc_client:stats'] = true,
+  ['mc_client:version'] = true,
   ['md5_context:digest'] = true,
   ['sha1_context:digest'] = true,
   ['socket:listen'] = true,
@@ -452,45 +475,5 @@ for _, module in ipairs(sorted_modules) do
 end
 
 -- Join the blocks of Markdown source and write them to the 1st file.
-local mkd_source = table.concat(blocks, '\n\n')
-local output = assert(io.open(arg[1], 'w'))
-assert(output:write(mkd_source))
-assert(output:close())
+io.write(table.concat(blocks, '\n\n'))
 
--- Convert Markdown to HTML and apply page template. {{{1
-
-local status, markdown = pcall(require, 'discount')
-if not status then markdown = require 'markdown' end
-
--- Generate and write the HTML output to the 2nd file. This isn't actually used
--- on http://peterodding.com/code/lua/apr/docs/ but does enable immediate
--- feedback when updating the documentation.
-local output = assert(io.open(arg[2], 'w'))
-assert(output:write([[
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
-"http://www.w3.org/TR/html4/strict.dtd">
-<html>
- <head>
-  <title>Lua/APR binding documentation</title>
-  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-  <style type="text/css">
-    body { font-family: sans-serif; padding: 1em 30% 10em 1em; cursor: default; }
-    a:link, a:visited { color: #000080; }
-    a:hover, a:active { color: #F00; }
-    pre, code, tt { font-family: Monaco, Consolas, monospace; }
-    pre, code { border: 1px solid #CCC; background: #F0F0F0; }
-    pre code, h1 code, h2 code, h3 code, h4 code, h5 code, h6 code { border: none; background: none; }
-    pre { padding: .3em; margin: 0 4em 0 2em; }
-    code { padding: .05em .2em; }
-    pre code { padding: none; }
-    p, li { text-align: justify; line-height: 1.75em; }
-    h1 { margin: 0; padding: 0 30% 0 0; color: #AAA; text-shadow: #000 1px 1px 0; }
-    h2, h3 { border-bottom: 2px solid #F6F6F6; margin: 2em 0 0 0; padding-left: 0.5em; }
-    h2 a:link, h2 a:visited, h3 a:link, h3 a:visited { padding: .2em; text-decoration: none; color: inherit; }
-    h2 a:hover, h3 a:hover { color: #F00; }
-  </style>
- </head>
- <body>]], markdown(mkd_source), [[
- </body>
-</html>]]))
-assert(output:close())
